@@ -1,11 +1,12 @@
-#---- Helper functions ----
+#---- Helper functions (internal) ----
 sss <- function(n, k, g) {
-  g / (g - 1) * (n - 1) / (n - k)
+  g / (g - 1L) * (n - 1L) / (n - k)
 }
 
 #---- Variance matrix ----
-rs_var <- function(u, Z, X = Z, ids = seq_len(nrow(X)), df = sss(nrow(X), ncol(X), nlevels(ids))) {
+rs_var <- function(u, Z, X = Z, ids = seq_len(nrow(X)), df = NULL) {
   ids <- as.factor(ids)
+  if (is.null(df)) df <- sss(nrow(X), ncol(X), nlevels(ids))
   # the meat
   ug <- split.data.frame(u, ids)
   Zg <- split.data.frame(Z, ids)
@@ -19,4 +20,4 @@ rs_var <- function(u, Z, X = Z, ids = seq_len(nrow(X)), df = sss(nrow(X), ncol(X
   # put the sandwich together
   vcov <- tcrossprod(B %*% V, B)
   df * vcov
-}
\ No newline at end of file
+}
